import * as ts from 'typescript';
export declare class MetadataGenerator {
    static current: MetadataGenerator;
    readonly nodes: ts.Node[];
    readonly typeChecker: ts.TypeChecker;
    private readonly program;
    private referenceTypes;
    static IsExportedNode(node: ts.Node): boolean;
    constructor(entryFile: string);
    Generate(): Metadata;
    TypeChecker(): ts.TypeChecker;
    AddReferenceType(referenceType: ReferenceType): void;
    GetReferenceType(typeName: string): ReferenceType;
    private buildControllers();
}
export interface Metadata {
    Controllers: Controller[];
    ReferenceTypes: {
        [typeName: string]: ReferenceType;
    };
}
export interface Controller {
    location: string;
    methods: Method[];
    name: string;
    path: string;
}
export interface Method {
    description: string;
    example: any;
    method: string;
    name: string;
    parameters: Parameter[];
    path: string;
    type: Type;
}
export interface Parameter {
    description: string;
    in: string;
    name: string;
    required: boolean;
    type: Type;
}
export declare type Type = PrimitiveType | ReferenceType | ArrayType;
export declare type PrimitiveType = string;
export interface ReferenceType {
    description: string;
    name: string;
    properties: Property[];
}
export interface Property {
    description: string;
    name: string;
    type: Type;
    required: boolean;
}
export interface ArrayType {
    elementType: Type;
}
