"use strict";
const metadataGenerator_1 = require('../../../../src/metadataGeneration/metadataGenerator');
const specGenerator_1 = require('../../../../src/swagger/specGenerator');
const verifyPath_1 = require('../../utilities/verifyPath');
const verifyParameter_1 = require('../../utilities/verifyParameter');
const defaultOptions_1 = require('../../../fixtures/defaultOptions');
describe('DELETE route generation', () => {
    const metadata = new metadataGenerator_1.MetadataGenerator('./tests/fixtures/controllers/deleteController.ts').Generate();
    const spec = new specGenerator_1.SpecGenerator(metadata, defaultOptions_1.getDefaultOptions()).GetSpec();
    const baseRoute = '/DeleteTest';
    it('should generate a path for a DELETE route with no path argument', () => {
        verifyPath(baseRoute);
    });
    it('should generate a path for a DELETE route with a path argument', () => {
        const actionRoute = `${baseRoute}/Current`;
        verifyPath(actionRoute, false, true);
    });
    it('should generate a parameter for path parameters', () => {
        const actionRoute = `${baseRoute}/{numberPathParam}/{booleanPathParam}/{stringPathParam}`;
        const path = verifyPath(actionRoute, false, true);
        verifyParameter_1.VerifyPathableParameter(path.delete.parameters, 'booleanPathParam', 'boolean', 'path');
        verifyParameter_1.VerifyPathableParameter(path.delete.parameters, 'numberPathParam', 'integer', 'path');
        verifyParameter_1.VerifyPathableParameter(path.delete.parameters, 'stringPathParam', 'string', 'path');
    });
    it('should generate a parameter for query parameters', () => {
        const actionRoute = `${baseRoute}/{numberPathParam}/{booleanPathParam}/{stringPathParam}`;
        const path = verifyPath(actionRoute, false, true);
        verifyParameter_1.VerifyPathableParameter(path.delete.parameters, 'booleanParam', 'boolean', 'query');
        verifyParameter_1.VerifyPathableParameter(path.delete.parameters, 'numberParam', 'integer', 'query');
        verifyParameter_1.VerifyPathableParameter(path.delete.parameters, 'stringParam', 'string', 'query');
    });
    function verifyPath(route, isCollection, isNoContent) {
        return verifyPath_1.VerifyPath(spec, route, path => path.delete, isCollection, isNoContent);
    }
});
//# sourceMappingURL=deleteRoutes.spec.js.map