"use strict";
const verifyPath_1 = require('../../utilities/verifyPath');
const verifyParameter_1 = require('../../utilities/verifyParameter');
const specGenerator_1 = require('../../../../src/swagger/specGenerator');
const metadataGenerator_1 = require('../../../../src/metadataGeneration/metadataGenerator');
const defaultOptions_1 = require('../../../fixtures/defaultOptions');
const chai = require('chai');
describe('POST route generation', () => {
    const metadata = new metadataGenerator_1.MetadataGenerator('./tests/fixtures/controllers/postController.ts').Generate();
    const spec = new specGenerator_1.SpecGenerator(metadata, defaultOptions_1.getDefaultOptions()).GetSpec();
    const baseRoute = '/PostTest';
    it('should generate a path for a POST route with no path argument', () => {
        verifyPath(baseRoute);
    });
    it('should generate a path for a POST route with a path argument', () => {
        const actionRoute = `${baseRoute}/Location`;
        verifyPath(actionRoute);
    });
    it('should set a valid response type for collection responses', () => {
        const actionRoute = `${baseRoute}/Multi`;
        verifyPath(actionRoute, true);
    });
    it('should generate a parameter for path parameters', () => {
        const actionRoute = `${baseRoute}/WithId/{id}`;
        const path = verifyPath(actionRoute);
        verifyParameter_1.VerifyPathableParameter(path.post.parameters, 'id', 'integer', 'path');
    });
    it('should generate a parameter for body parameters', () => {
        const path = verifyPath(baseRoute);
        verifyParameter_1.VerifyBodyParameter(path.post.parameters, 'model', verifyPath_1.modelName, 'body');
    });
    it('should reject multiple body parameters', () => {
        chai.expect(() => {
            const invalidMetadata = new metadataGenerator_1.MetadataGenerator('./tests/fixtures/controllers/invalidPostController.ts').Generate();
            new specGenerator_1.SpecGenerator(invalidMetadata, defaultOptions_1.getDefaultOptions()).GetSpec();
        }).to.throw('Only one body parameter allowed per controller method.');
    });
    it('should be able to parse body and query parameters together', () => {
        const path = verifyPath(`${baseRoute}/WithBodyAndQueryParams`);
        verifyParameter_1.VerifyBodyParameter(path.post.parameters, 'model', verifyPath_1.modelName, 'body');
        verifyParameter_1.VerifyPathableParameter(path.post.parameters, 'query', 'string', 'query');
    });
    function verifyPath(route, isCollection) {
        return verifyPath_1.VerifyPath(spec, route, path => path.post, isCollection);
    }
});
//# sourceMappingURL=postRoutes.spec.js.map