"use strict";
const defaultOptions_1 = require('../../../fixtures/defaultOptions');
const metadataGenerator_1 = require('../../../../src/metadataGeneration/metadataGenerator');
const specGenerator_1 = require('../../../../src/swagger/specGenerator');
const verifyParameter_1 = require('../../utilities/verifyParameter');
const verifyPath_1 = require('../../utilities/verifyPath');
describe('PUT route generation', () => {
    const metadata = new metadataGenerator_1.MetadataGenerator('./tests/fixtures/controllers/putController.ts').Generate();
    const spec = new specGenerator_1.SpecGenerator(metadata, defaultOptions_1.getDefaultOptions()).GetSpec();
    const baseRoute = '/PutTest';
    it('should generate a path for a PUT route with no path argument', () => {
        verifyPath(baseRoute);
    });
    it('should generate a path for a PUT route with a path argument', () => {
        const actionRoute = `${baseRoute}/Location`;
        verifyPath(actionRoute);
    });
    it('should set a valid response type for collection responses', () => {
        const actionRoute = `${baseRoute}/Multi`;
        verifyPath(actionRoute, true);
    });
    it('should generate a parameter for path parameters', () => {
        const actionRoute = `${baseRoute}/WithId/{id}`;
        const path = verifyPath(actionRoute);
        verifyParameter_1.VerifyPathableParameter(path.put.parameters, 'id', 'integer', 'path');
    });
    it('should generate a parameter for body parameters', () => {
        const path = verifyPath(baseRoute);
        verifyParameter_1.VerifyBodyParameter(path.put.parameters, 'model', verifyPath_1.modelName, 'body');
    });
    function verifyPath(route, isCollection) {
        return verifyPath_1.VerifyPath(spec, route, path => path.put, isCollection);
    }
});
//# sourceMappingURL=putRoutes.spec.js.map